<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */

if ( ! function_exists( 'travel_ultimate_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Travel Ultimate Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_ultimate_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'travel_ultimate_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'travel_ultimate_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Travel Ultimate Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_ultimate_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'travel_ultimate_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'travel_ultimate_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Travel Ultimate Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_ultimate_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'travel_ultimate_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[top_section_enable]' )->value() );
}

/**
 * Check if cta section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_cta_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[cta_content_type]' )->value();
	return travel_ultimate_pro_is_cta_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[cta_content_type]' )->value();
	return travel_ultimate_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[cta_content_type]' )->value();
	return travel_ultimate_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if package section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[package_section_enable]' )->value() );
}

/**
 * Check if package section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_package_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[package_content_type]' )->value();
	return travel_ultimate_pro_is_package_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if package section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_package_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[package_content_type]' )->value();
	return travel_ultimate_pro_is_package_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if package section seperator.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_package_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[package_content_type]' )->value();
	return travel_ultimate_pro_is_package_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if package section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_package_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[package_content_type]' )->value();
	return travel_ultimate_pro_is_package_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if package section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[package_content_type]' )->value();
	return travel_ultimate_pro_is_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if tour cat is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_tour_cat_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[tour_content_type]' )->value();
	return travel_ultimate_pro_is_about_section_enable( $control ) && ( 'cat' == $content_type );
}

/**
 * Check if tour destination is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_tour_destinations_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[tour_content_type]' )->value();
	return travel_ultimate_pro_is_about_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if tour trip is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_tour_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[tour_content_type]' )->value();
	return travel_ultimate_pro_is_about_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if about section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[about_content_type]' )->value();
	return travel_ultimate_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[about_content_type]' )->value();
	return travel_ultimate_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[about_content_type]' )->value();
	return travel_ultimate_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if slider section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[slider_content_type]' )->value();
	return travel_ultimate_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_slider_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[slider_content_type]' )->value();
	return travel_ultimate_pro_is_slider_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if slider section content type is product.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_slider_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[slider_content_type]' )->value();
	return travel_ultimate_pro_is_slider_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[slider_content_type]' )->value();
	return travel_ultimate_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[slider_content_type]' )->value();
	return travel_ultimate_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is product-category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_slider_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[slider_content_type]' )->value();
	return travel_ultimate_pro_is_slider_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if guide section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_guide_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[guide_section_enable]' )->value() );
}

/**
 * Check if guide section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_guide_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[guide_content_type]' )->value();
	return travel_ultimate_pro_is_guide_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if guide section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_guide_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[guide_content_type]' )->value();
	return travel_ultimate_pro_is_guide_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if guide section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_guide_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[guide_content_type]' )->value();
	return travel_ultimate_pro_is_guide_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if guide section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_guide_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[guide_content_type]' )->value();
	return travel_ultimate_pro_is_guide_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if guide section seperator.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_guide_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[guide_content_type]' )->value();
	return travel_ultimate_pro_is_guide_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if destination section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[destination_section_enable]' )->value() );
}

/**
 * Check if destination section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[destination_content_type]' )->value();
	return travel_ultimate_pro_is_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if destination section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[destination_content_type]' )->value();
	return travel_ultimate_pro_is_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if destination section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_dest_destinations_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[destination_content_type]' )->value();
	return travel_ultimate_pro_is_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if destination section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_destination_section_wp_travel( $control ) {
	return travel_ultimate_pro_is_dest_destinations_enable( $control ) || travel_ultimate_pro_is_destination_section_content_trip_enable( $control );
}
/**
 * Check if destination section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[destination_content_type]' )->value();
	return travel_ultimate_pro_is_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if destination section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[destination_content_type]' )->value();
	return travel_ultimate_pro_is_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if destination section seperator.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_destination_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[destination_content_type]' )->value();
	return travel_ultimate_pro_is_destination_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if event section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_event_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[event_section_enable]' )->value() );
}

/**
 * Check if event section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_event_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[event_content_type]' )->value();
	return travel_ultimate_pro_is_event_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_event_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[event_content_type]' )->value();
	return travel_ultimate_pro_is_event_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if event section content type is trip.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_dest_events_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[event_content_type]' )->value();
	return travel_ultimate_pro_is_event_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if event section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_event_section_wp_travel( $control ) {
	return travel_ultimate_pro_is_dest_events_enable( $control ) || travel_ultimate_pro_is_event_section_content_trip_enable( $control );
}
/**
 * Check if event section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_event_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[event_content_type]' )->value();
	return travel_ultimate_pro_is_event_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if event section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_event_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[event_content_type]' )->value();
	return travel_ultimate_pro_is_event_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section seperator.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_event_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[event_content_type]' )->value();
	return travel_ultimate_pro_is_event_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post', 'trip' ) ) );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[testimonial_content_type]' )->value();
	return travel_ultimate_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[testimonial_content_type]' )->value();
	return travel_ultimate_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[testimonial_content_type]' )->value();
	return travel_ultimate_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[testimonial_content_type]' )->value();
	return travel_ultimate_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[testimonial_content_type]' )->value();
	return travel_ultimate_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[testimonial_content_type]' )->value();
	return travel_ultimate_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if counter section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[counter_section_enable]' )->value() );
}

/**
 * Check if service section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[service_content_type]' )->value();
	return travel_ultimate_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[service_content_type]' )->value();
	return travel_ultimate_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[service_content_type]' )->value();
	return travel_ultimate_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[service_content_type]' )->value();
	return travel_ultimate_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if team section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[team_content_type]' )->value();
	return travel_ultimate_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[team_content_type]' )->value();
	return travel_ultimate_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[team_content_type]' )->value();
	return travel_ultimate_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if subscription section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[subscription_section_enable]' )->value() );
}

/*medical reason*/

/**
 * Check if reason section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_reason_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[reason_section_enable]' )->value() );
}

/**
 * Check if reason section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_reason_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[reason_content_type]' )->value();
	return travel_ultimate_pro_is_reason_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if reason section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_reason_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[reason_content_type]' )->value();
	return travel_ultimate_pro_is_reason_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if reason section content type is custom.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_reason_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[reason_content_type]' )->value();
	return travel_ultimate_pro_is_reason_section_enable( $control ) && ( 'custom' == $content_type );
}

/*end medical reason*/

/*masonry*/

/**
 * Check if product section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_masonry_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[masonry_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/* end masonry*/

/**
 * Check if product section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if product section content type is product.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[product_content_type]' )->value();
	return travel_ultimate_pro_is_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product section content type is product category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[product_content_type]' )->value();
	return travel_ultimate_pro_is_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

//featured section
function travel_ultimate_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[featured_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/*latest-product*/

/**
 * Check if product section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_latest_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[latest_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if product section content type is product.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_latest_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[latest_product_content_type]' )->value();
	return travel_ultimate_pro_is_latest_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product section content type is product category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_latest_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[latest_product_content_type]' )->value();
	return travel_ultimate_pro_is_latest_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*end latest-product*/

/*featured_posts section*/

/**
 * Check if featured_posts section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_featured_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[featured_posts_section_enable]' )->value() );
}

/**
 * Check if featured_posts section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_featured_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[featured_posts_content_type]' )->value();
	return travel_ultimate_pro_is_featured_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_posts section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_featured_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[featured_posts_content_type]' )->value();
	return travel_ultimate_pro_is_featured_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_posts section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_featured_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[featured_posts_content_type]' )->value();
	return travel_ultimate_pro_is_featured_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*end featured_posts section*/

/*popular_posts section*/

/**
 * Check if popular_posts section is enabled.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_popular_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[popular_posts_section_enable]' )->value() );
}

/**
 * Check if popular_posts section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_popular_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[popular_posts_content_type]' )->value();
	return travel_ultimate_pro_is_popular_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_posts section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_popular_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[popular_posts_content_type]' )->value();
	return travel_ultimate_pro_is_popular_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_posts section content type is post.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_popular_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[popular_posts_content_type]' )->value();
	return travel_ultimate_pro_is_popular_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*end popular_posts section*/

/*recent section*/

function travel_ultimate_pro_is_recent_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[recent_section_enable]' )->value() );
}

function travel_ultimate_pro_is_recent_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[recent_content_type]' )->value();
	return travel_ultimate_pro_is_recent_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_recent_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[recent_content_type]' )->value();
	return travel_ultimate_pro_is_recent_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_recent_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[recent_content_type]' )->value();
	return travel_ultimate_pro_is_recent_section_enable( $control ) && ( 'category' == $content_type );
}

/*end recent section*/

/*sports_news section*/

function travel_ultimate_pro_is_sports_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[sports_news_section_enable]' )->value() );
}

function travel_ultimate_pro_is_sports_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[sports_news_content_type]' )->value();
	return travel_ultimate_pro_is_sports_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if sports_news section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_sports_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[sports_news_content_type]' )->value();
	return travel_ultimate_pro_is_sports_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if sports_news section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_sports_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[sports_news_content_type]' )->value();
	return travel_ultimate_pro_is_sports_news_section_enable( $control ) && ( 'category' == $content_type );
}

/*end sports_news section*/

/*latest_posts section*/

function travel_ultimate_pro_is_latest_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_ultimate_pro_theme_options[latest_posts_section_enable]' )->value() );
}

function travel_ultimate_pro_is_latest_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[latest_posts_content_type]' )->value();
	return travel_ultimate_pro_is_latest_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_posts section content type is page.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_latest_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[latest_posts_content_type]' )->value();
	return travel_ultimate_pro_is_latest_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_posts section content type is category.
 *
 * @since Travel Ultimate Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_ultimate_pro_is_latest_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_ultimate_pro_theme_options[latest_posts_content_type]' )->value();
	return travel_ultimate_pro_is_latest_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/*end latest_posts section*/