<?php
/**
 * Event Section options
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */

// Add Event section
$wp_customize->add_section( 'travel_ultimate_pro_event_section', array(
	'title'             => esc_html__( 'Event','travel-ultimate-pro' ),
	'description'       => esc_html__( 'Event Section options.', 'travel-ultimate-pro' ),
	'panel'             => 'travel_ultimate_pro_front_page_panel',
) );

// Event content enable control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_section_enable]', array(
	'default'			=> 	$options['event_section_enable'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Ultimate_Pro_Switch_Control( $wp_customize, 'travel_ultimate_pro_theme_options[event_section_enable]', array(
	'label'             => esc_html__( 'Event Section Enable', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_event_section',
	'on_off_label' 		=> travel_ultimate_pro_switch_options(),
) ) );

// event title setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[event_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_event_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[event_title]', array(
		'selector'            => '#travel-events .section-header h2.section-title',
		'settings'            => 'travel_ultimate_pro_theme_options[event_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_event_title_partial',
    ) );
}

if ( $options['home_layout'] == 'default-design' ):

// event description setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[event_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_event_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_event_section_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[event_subtitle]', array(
		'selector'            => '#travel-events .section-header span.section-subtitle',
		'settings'            => 'travel_ultimate_pro_theme_options[event_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_event_subtitle_partial',
    ) );
}
endif;

if ( $options['home_layout'] !== 'default-design' ):
// event description setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_description]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[event_description]', array(
	'label'           	=> esc_html__( 'Description', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_event_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_event_section_enable',
	'type'				=> 'textarea',
) );
endif;

// event number control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_count]', array(
	'default'          	=> $options['event_count'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_number_range',
	'validate_callback' => 'travel_ultimate_pro_validate_event_count',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[event_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-ultimate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_event_section',
	'active_callback'   => 'travel_ultimate_pro_is_event_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Event content type control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_content_type]', array(
	'default'          	=> $options['event_content_type'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_select',
) );

$choices = array( 
		'page' 		=> esc_html__( 'Page', 'travel-ultimate-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-ultimate-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-ultimate-pro' ),
	);
if ( class_exists( 'WP_Travel' ) ) {
	$choices['trip'] = esc_html__( 'Trip', 'travel-ultimate-pro' );
	$choices['destination'] = esc_html__( 'Destination', 'travel-ultimate-pro' );
}

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[event_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_event_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_ultimate_pro_is_event_section_enable',
	'choices'			=> $choices,
) );

for ( $i = 1; $i <= $options['event_count']; $i++ ) :
	// event pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[event_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-ultimate-pro' ), $i ),
		'section'           => 'travel_ultimate_pro_event_section',
		'choices'			=> travel_ultimate_pro_page_choices(),
		'active_callback'	=> 'travel_ultimate_pro_is_event_section_content_page_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[event_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-ultimate-pro' ), $i ),
		'section'           => 'travel_ultimate_pro_event_section',
		'choices'			=> travel_ultimate_pro_post_choices(),
		'active_callback'	=> 'travel_ultimate_pro_is_event_section_content_post_enable',
	) ) );

	if ( class_exists( 'WP_Travel' ) ) {
		// slider trip drop down chooser control and setting
		$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_content_trip_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[event_content_trip_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Trip %d', 'travel-ultimate-pro' ), $i ),
			'section'           => 'travel_ultimate_pro_event_section',
			'choices'			=> travel_ultimate_pro_trip_choices(),
			'active_callback'	=> 'travel_ultimate_pro_is_event_section_content_trip_enable',
		) ) );
	}

	if ( $options['home_layout'] !== 'fifth-design' ):
	// event btn setting and control
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_read_more_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_ultimate_pro_theme_options[event_read_more_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Read more text %d', 'travel-ultimate-pro' ), $i ),
		'section'        	=> 'travel_ultimate_pro_event_section',
		'active_callback' 	=> 'travel_ultimate_pro_is_event_section_enable',
	) );
	endif;


	// event hr setting and control
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travel_Ultimate_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_ultimate_pro_theme_options[event_hr_'. $i .']',
		array(
			'section'         => 'travel_ultimate_pro_event_section',
			'active_callback' => 'travel_ultimate_pro_is_event_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[event_content_category]', array(
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[event_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-ultimate-pro' ),
	'description'      	=> esc_html__( 'Note: Event selected no of posts will be shown from selected category', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_event_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_ultimate_pro_is_event_section_content_category_enable'
) ) );

if ( class_exists( 'WP_Travel' ) ) {
	// Add dropdown events setting and control.
	$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[dest_events]', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[dest_events]', array(
		'label'             => esc_html__( 'Select events', 'travel-ultimate-pro' ),
		'description'      	=> esc_html__( 'Note: Selected event\'s no of posts will be shown from selected category', 'travel-ultimate-pro' ),
		'section'           => 'travel_ultimate_pro_event_section',
		'type'              => 'dropdown-taxonomies',
		'taxonomy'			=> 'travel_locations',
		'active_callback'	=> 'travel_ultimate_pro_is_dest_events_enable'
	) ) );
}


if ( $options['home_layout'] == 'default-design' ):

// event button setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_btn]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_btn'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[event_btn]', array(
	'label'           	=> esc_html__( 'Button', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_event_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_event_section_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[event_btn]', array(
		'selector'            => '#travel-events .section-header span.section-subtitle',
		'settings'            => 'travel_ultimate_pro_theme_options[event_btn]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_event_btn_partial',
    ) );
}

// event button url setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[event_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=> $options['event_btn_url'],
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[event_btn_url]', array(
	'label'           	=> esc_html__( 'Button URL', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_event_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_event_section_enable',
) );

endif;