<?php
/**
 * latest posts Section options
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */

// Add latest posts section
$wp_customize->add_section( 'travel_ultimate_pro_latest_posts_section', array(
	'title'             => esc_html__( 'Latest Posts','travel-ultimate-pro' ),
	'panel'             => 'travel_ultimate_pro_front_page_panel',
) );

// latest posts content enable control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[latest_posts_section_enable]', array(
	'default'			=> 	$options['latest_posts_section_enable'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Ultimate_Pro_Switch_Control( $wp_customize, 'travel_ultimate_pro_theme_options[latest_posts_section_enable]', array(
	'label'             => esc_html__( 'Latest Posts Section Enable', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_latest_posts_section',
	'on_off_label' 		=> travel_ultimate_pro_switch_options(),
) ) );

	// latest posts title setting and control
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[latest_posts_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['latest_posts_title'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'travel_ultimate_pro_theme_options[latest_posts_title]', array(
		'label'           	=> esc_html__( 'Title', 'travel-ultimate-pro' ),
		'section'        	=> 'travel_ultimate_pro_latest_posts_section',
		'active_callback' 	=> 'travel_ultimate_pro_is_latest_posts_section_enable',
		'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[latest_posts_title]', array(
			'selector'            => '#magazine-latest-posts h2.section-title',
			'settings'            => 'travel_ultimate_pro_theme_options[latest_posts_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'travel_ultimate_pro_latest_posts_title_partial',
			) );
	}

	// latest posts content type control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[latest_posts_content_type]', array(
		'default'          	=> $options['latest_posts_content_type'],
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'travel_ultimate_pro_theme_options[latest_posts_content_type]', array(
		'label'             => esc_html__( 'Content Type', 'travel-ultimate-pro' ),
		'section'           => 'travel_ultimate_pro_latest_posts_section',
		'type'				=> 'select',
		'active_callback' 	=> 'travel_ultimate_pro_is_latest_posts_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'travel-ultimate-pro' ),
			'post' 		=> esc_html__( 'Post', 'travel-ultimate-pro' ),
			'category' 	=> esc_html__( 'Category', 'travel-ultimate-pro' ),
		),
	) );

	// Event social icons number control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[latest_posts_count]', array(
		'default'          	=> $options['latest_posts_count'],
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_number_range',
		'validate_callback' => 'travel_ultimate_pro_validate_latest_posts_count',
	) );

	$wp_customize->add_control( 'travel_ultimate_pro_theme_options[latest_posts_count]', array(
		'label'             => esc_html__( 'Number of Posts', 'travel-ultimate-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-ultimate-pro' ),
		'section'           => 'travel_ultimate_pro_latest_posts_section',
		'active_callback'   => 'travel_ultimate_pro_is_latest_posts_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 12,
			'style' => 'width: 100px;'
			),
	) );

	for ( $i = 1; $i <= $options['latest_posts_count']; $i++ ) :
		// latest posts pages drop down chooser control and setting
		$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[latest_posts_content_page_' . $i . ']', array(
			'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[latest_posts_content_page_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-ultimate-pro' ), $i ),
			'section'           => 'travel_ultimate_pro_latest_posts_section',
			'choices'			=> travel_ultimate_pro_page_choices(),
			'active_callback'	=> 'travel_ultimate_pro_is_latest_posts_section_content_page_enable',
		) ) );

		// latest posts posts drop down chooser control and setting
		$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[latest_posts_content_post_' . $i . ']', array(
			'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[latest_posts_content_post_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-ultimate-pro' ), $i ),
			'section'           => 'travel_ultimate_pro_latest_posts_section',
			'choices'			=> travel_ultimate_pro_post_choices(),
			'active_callback'	=> 'travel_ultimate_pro_is_latest_posts_section_content_post_enable',
		) ) );
	endfor;

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[latest_posts_content_category]', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_single_category',
	) ) ;

	$wp_customize->add_control( new Travel_Ultimate_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[latest_posts_content_category]', array(
		'label'             => esc_html__( 'Select Category', 'travel-ultimate-pro' ),
		'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-ultimate-pro' ),
		'section'           => 'travel_ultimate_pro_latest_posts_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'travel_ultimate_pro_is_latest_posts_section_content_category_enable'
	) ) );