<?php
/**
 * CTA section
 *
 * This is the template for the content of cta section
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */
if ( ! function_exists( 'travel_ultimate_pro_add_cta_section' ) ) :
    /**
    * Add cta section
    *
    *@since Travel Ultimate Pro 1.0.0
    */
    function travel_ultimate_pro_add_cta_section() {
    	$options = travel_ultimate_pro_get_theme_options();
        // Check if cta is enabled on frontpage
        $cta_enable = apply_filters( 'travel_ultimate_pro_section_status', true, 'cta_section_enable' );

        if ( true !== $cta_enable ) {
            return false;
        }
        // Get cta section details
        $section_details = array();
        $section_details = apply_filters( 'travel_ultimate_pro_filter_cta_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render cta section now.
        travel_ultimate_pro_render_cta_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_ultimate_pro_get_cta_section_details' ) ) :
    /**
    * cta section details.
    *
    * @since Travel Ultimate Pro 1.0.0
    * @param array $input cta section details.
    */
    function travel_ultimate_pro_get_cta_section_details( $input ) {
        $options = travel_ultimate_pro_get_theme_options();

        // Content type.
        $cta_content_type  = $options['cta_content_type'];
        
        $content = array();
        switch ( $cta_content_type ) {
        	
            case 'page':
                $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['cta_content_post'] ) ? $options['cta_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'trip':
                $trip_id = ! empty( $options['cta_content_trip'] ) ? $options['cta_content_trip'] : '';
                $args = array(
                    'post_type'         => 'itineraries',
                    'p'                 => $trip_id,
                    'posts_per_page'    => 1,
                    'ignore_sticky_posts'   => true,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $cta_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = travel_ultimate_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// cta section content details.
add_filter( 'travel_ultimate_pro_filter_cta_section_details', 'travel_ultimate_pro_get_cta_section_details' );


if ( ! function_exists( 'travel_ultimate_pro_render_cta_section' ) ) :
  /**
   * Start cta section
   *
   * @return string cta content
   * @since Travel Ultimate Pro 1.0.0
   *
   */
   function travel_ultimate_pro_render_cta_section( $content_details = array() ) {
        $options = travel_ultimate_pro_get_theme_options();
        $content_type = $options['cta_content_type'];
        $btn_label = ( $options['cta_btn_label'] ) == '' ? $options['cta_btn_label'] : esc_html__( 'Learn More', 'travel-ultimate-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php if ( $options['home_layout'] == 'default-design' ): ?>
        <div id="call-to-action" class="relative page-section">
            <div class="wrapper">
                <?php foreach ( $content_details as $content ) : ?>
                    <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        </div>

                        <div class="entry-container">
                            <div class="entry-meta">
                                <ul class="post-categories">
                                    <?php 
                                    if ( 'trip' === $content_type ) { 
                                        $terms = get_the_terms( $content['id'], 'travel_locations' );
                                        if ( is_array( $terms ) && count( $terms ) > 0 ) {
                                            foreach ( $terms as $term ) {
                                                ?>
                                                <li><a href="<?php echo esc_url( get_term_link( $term->term_id ) ) ?>"><?php echo esc_html( $term->name ); ?></a></li>
                                                <?php 
                                            }
                                        } 
                                    } elseif ( 'page' != $content_type ) {
                                        $cats = get_the_category( $content['id'] );
                                        foreach ( $cats as $cat ) { 
                                            ?>
                                            <li><a href="<?php echo esc_url( get_category_link( $cat->term_id ) ); ?>"><?php echo esc_html( get_cat_name( $cat->term_id ) ); ?></a></li>
                                            <?php 
                                        } 
                                    }
                                    ?>

                                </ul>
                            </div><!-- .entry-meta -->

                            <header class="entry-header">
                                <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </header>

                            <?php if ( 'trip' === $content_type ) { ?>
                            <div class="clearfix">
                                <?php wp_travel_single_trip_rating( $content['id'] );  ?>
                            </div><!-- .clearfix -->
                            <?php } ?>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <?php if ( 'trip' === $content_type ) { ?>
                            <?php do_action( 'wp_travel_single_trip_after_title', $content['id'] ) ; ?>
                            <?php } ?>


                            <?php if ( ! empty( $options['cta_btn_label'] ) ) : ?>
                                <div class="view-all">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['cta_btn_label'] ); ?></a>
                                </div><!-- .view-all -->
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach; ?>
            </div><!-- .wrapper -->
        </div><!-- .hero-cta-wrapper -->
    <?php endif;

    if ( $options['home_layout'] == 'sixth-design' ):

        foreach ( $content_details as $content ) : ?>

            <div id="charity-cta" class="relative page-section" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <header class="entry-header">
                        <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                    </header>

                    <div class="business-read-more">
                        <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['cta_btn_label'] ); ?></a>
                    </div><!-- .business-read-more -->
                </div><!-- .wrapper -->
            </div>

        <?php endforeach;

        endif;

    }
endif;