<?php
/**
* Popular Post section
*
* This is the template for the content of featured_post section
*
* @package Theme Palace
* @subpackage Travel Ultimate Pro
* @since Travel Ultimate Pro 1.0.0
*/


$options = travel_ultimate_pro_get_theme_options();

if( $options['popular_posts_section_enable'] !== false ):

// Content type.
$popular_posts_content_type  = $options['popular_posts_content_type'];
$popular_posts_count = ! empty( $options['popular_posts_count'] ) ? $options['popular_posts_count'] : 4;

$content_details = array();
switch ( $popular_posts_content_type ) {

    case 'page':
    $page_ids = array();

    for ( $i = 1; $i <= $popular_posts_count; $i++ ) {
        if ( ! empty( $options['popular_posts_content_page_' . $i] ) )
            $page_ids[] = $options['popular_posts_content_page_' . $i];
    }

    $args = array(
        'post_type'         => 'page',
        'post__in'          => ( array ) $page_ids,
        'posts_per_page'    => absint( $popular_posts_count ),
        'orderby'           => 'post__in',
        );                    
    break;

    case 'post':
    $post_ids = array();

    for ( $i = 1; $i <= $popular_posts_count; $i++ ) {
        if ( ! empty( $options['popular_posts_content_post_' . $i] ) )
            $post_ids[] = $options['popular_posts_content_post_' . $i];
    }
    $args = array(
        'post_type'         => 'post',
        'post__in'          => ( array ) $post_ids,
        'posts_per_page'    => absint( $popular_posts_count ),
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                    
    break;

    case 'category':
    $cat_ids = ! empty( $options['popular_posts_content_category'] ) ? $options['popular_posts_content_category'] : '';
    $args = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $popular_posts_count ),
        'cat'               => absint( $cat_ids ),
        'ignore_sticky_posts'   => true,
        );                    
    break;

    default:
    break;
}


// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) : 
    while ( $query->have_posts() ) : $query->the_post();
        $page_post['id']        = get_the_id();
        $page_post['auth_id']   = get_the_author_meta('ID');
        $page_post['title']     = get_the_title();
        $page_post['url']       = get_the_permalink();
        $page_post['excerpt']   = travel_ultimate_pro_trim_content( 45 );
        $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
        // Push to the main array.
        array_push( $content_details, $page_post );
    endwhile;
endif;
wp_reset_postdata();
?>

<div id="magazine-popular-posts" class="relative page-section">
    <?php if( !empty( $options['popular_title'] ) ): ?>
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $options['popular_title'] ); ?></h2>
        </div><!-- .section-header -->
    <?php endif; ?>

    <div class="section-content clear">

        <?php foreach ( $content_details as $content ) : ?>
            <article class="has-post-thumbnail">
                <?php if( !empty( $content['image'] ) && !empty( $content['url'] ) ): ?>
                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                    </div><!-- .featured-image -->
                <?php endif; ?>
                <div class="entry-container">
                    <?php if ( $popular_posts_content_type !== 'page' ) : ?>
                        <div class="entry-meta">
                            <span class="cat-links">
                             <?php the_category( '', '', $content['id'] ); ?>
                         </span><!-- .cat-links -->                        
                     </div><!-- .entry-meta -->
                 <?php endif; ?>

                 <header class="entry-header">
                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                </header>

                <div class="entry-meta author-posted-on">
                    <?php
                    echo travel_ultimate_pro_author( $content['auth_id'] );

                    travel_ultimate_pro_posted_on( $content['id'] );
                    ?> 
                </div><!-- .entry-meta -->   

                <div class="entry-content">
                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                </div><!-- .entry-content -->
            </div><!-- .entry-container -->
        </article>
    <?php endforeach; ?>

</div><!-- .section-content -->
</div><!-- #magazine-popular-posts -->

<?php endif; ?>



